//[mahjong-utils](../../index.md)/[mahjongutils.shanten](index.md)/[throwOnValidationError](throw-on-validation-error.md)

# throwOnValidationError

[common]\
fun [CommonShantenArgs](-common-shanten-args/index.md).[throwOnValidationError](throw-on-validation-error.md)()

fun [FuroChanceShantenArgs](-furo-chance-shanten-args/index.md).[throwOnValidationError](throw-on-validation-error.md)()
